"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var PermissionsUtil = (function () {
    function PermissionsUtil() {
    }
    PermissionsUtil.prototype.getAudioPermissionStatus = function () {
        var permission = AVAudioSession.sharedInstance().recordPermission();
        switch (permission) {
            case 1735552628:
                return PermissionStatus.Granted;
            case 1684369017:
                return PermissionStatus.Denied;
            case 1970168948:
                return PermissionStatus.Undetermined;
        }
    };
    PermissionsUtil.prototype.requestAudioPermission = function () {
        return new Promise(function (resolve, reject) {
            AVAudioSession.sharedInstance().requestRecordPermission(function (response) {
                resolve(response);
            });
        });
    };
    PermissionsUtil.prototype.getLocationPermissionStatus = function (always) {
        if (always === void 0) { always = false; }
        var permission = CLLocationManager.authorizationStatus();
        return getLocationPermissionStatusFromCLAuthorizationStatus(permission, always);
    };
    PermissionsUtil.prototype.requestLocationPermission = function (always) {
        var _this = this;
        if (always === void 0) { always = false; }
        var permissionStatus = this.getLocationPermissionStatus(always);
        if (!this._locationListener) {
            this._locationListener = new LocationListener();
        }
        if (!this._locationManager) {
            this._locationManager = new CLLocationManager();
            this._locationManager.delegate = this._locationListener;
            this._locationManager.desiredAccuracy = kCLLocationAccuracyBest;
        }
        if (always) {
            console.log("Requesting always permission");
            this._locationListener.setAlways();
            this._locationManager.requestAlwaysAuthorization();
        }
        else {
            console.log("Requesting in use permission");
            this._locationListener.setWheninUse();
            this._locationManager.requestWhenInUseAuthorization();
        }
        return new Promise(function (resolve, reject) {
            if (permissionStatus !== PermissionStatus.Undetermined) {
                resolve(permissionStatus);
            }
            _this._locationListener.setResolveCallback(resolve);
        });
    };
    PermissionsUtil.prototype.getCameraAuthorizationStatus = function () {
        var status = AVCaptureDevice.authorizationStatusForMediaType(AVMediaTypeVideo);
        switch (status) {
            case 3:
                return PermissionStatus.Granted;
            case 2:
                return PermissionStatus.Denied;
            case 0:
                return PermissionStatus.Undetermined;
            case 1:
                return PermissionStatus.Denied;
        }
    };
    PermissionsUtil.prototype.requestCameraPermission = function () {
        return new Promise(function (resolve) {
            AVCaptureDevice.requestAccessForMediaTypeCompletionHandler(AVMediaTypeVideo, resolve);
        });
    };
    return PermissionsUtil;
}());
exports.PermissionsUtil = PermissionsUtil;
var LocationListener = (function (_super) {
    __extends(LocationListener, _super);
    function LocationListener() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LocationListener.prototype.setAlways = function () {
        this._always = true;
    };
    LocationListener.prototype.setResolveCallback = function (resolve) {
        this._resolve = resolve;
    };
    LocationListener.prototype.setWheninUse = function () {
        this._always = false;
    };
    LocationListener.prototype.locationManagerDidChangeAuthorizationStatus = function (manager, status) {
        if (!this._didSetup) {
            this._didSetup = true;
            return;
        }
        var res = getLocationPermissionStatusFromCLAuthorizationStatus(status, this._always);
        this._resolve(res);
    };
    LocationListener.ObjCProtocols = [CLLocationManagerDelegate];
    return LocationListener;
}(NSObject));
function getLocationPermissionStatusFromCLAuthorizationStatus(status, always) {
    if (always === void 0) { always = false; }
    switch (status) {
        case 3:
            return PermissionStatus.Granted;
        case 3:
            return PermissionStatus.Granted;
        case 4:
            if (always) {
                return PermissionStatus.Denied;
            }
            return PermissionStatus.Granted;
        case 2:
            return PermissionStatus.Denied;
        case 0:
            return PermissionStatus.Undetermined;
        case 1:
            return PermissionStatus.Denied;
    }
}
var PermissionStatus;
(function (PermissionStatus) {
    PermissionStatus["Granted"] = "granted";
    PermissionStatus["Denied"] = "denied";
    PermissionStatus["Undetermined"] = "undetermined";
})(PermissionStatus = exports.PermissionStatus || (exports.PermissionStatus = {}));
exports.iOsPermissisonsUtil = new PermissionsUtil();
//# sourceMappingURL=permissions-util.js.map